Dijit Theme Tester

Loading themeTester ...
Enabled Item
Disabled Item
Cut
Copy
Paste
Enabled Submenu
Submenu Item One
Submenu Item Two
Deeper Submenu
Sub-sub-menu Item One
Sub-sub-menu Item Two
Disabled Submenu
Submenu Item One
Submenu Item Two
Different popup
Different popup

# Dijit Theme Test Page

## Tooltips:

- rich text tooltip Embedded bold RICH text weirdness!
- anchor tooltip tooltip on anchor

## Dialogs:

- show Modal Dialog

Show Tooltip Dialog

User: |
Password: |

## Dijit Color Palette(7x10)

Test color is:

## Various Form Elements:

Standard Dijit CheckBox
Disabled Dijit
Checked and Disabled Dijit

Radio group #1: news talk weather (disabled)

Radio group #2: (no default value, and has breaks)
top 40
oldies
country
(Note if using keyboard: tab to navigate, and use arrow or space to select)

## dijit.form.NumberSpinner max=100

## dijit.form.Textarea: (sans any styling...)

Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.

## dijit.form.ComboBox

US State test 2:

1. 0
2. 100

Slider2 Value:

## Sliders

1. lowest
2. normal
3. highest

Value:

1. small
2. medium
3. large

## ProgressBar

Indeterminate:

## TitlePane (nested)

This is a title pane, containing another title pane ...

And this is the inner title pane...

Sed sollicitudin suscipit risus. Nam ullamcorper. Sed nisl lectus, pellentesque nec, malesuada eget, ornare a, libero. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

And this is the closing line for the outer title pane.

## HTML After, check indent

## Simple, drop down & combo buttons

Buttons can do an action, display a menu, or both:

## Sizing

Short button, tall buttons, big buttons, small buttons... These buttons size to their content (just like <button>).

## Customized buttons

Dojo users can mix in their styles. Here's an example:

## dijit.Editor:

<ul> <li>Lorem <a href="http://dojotoolkit.org">and a link</a>, what do you think?</li> <li>This is the Editor with a Toolbar attached.</li> </ul>

## dijit.InlineEditBox + dijit.form.TextBox on <h3>

(HTML before)

### Edit me - I trigger the onChange callback

(HTML after)

## dijit.InlineEditBox + dijit.form.Textarea

(HTML before)

I'm one big paragraph. Go ahead and edit me. I dare you. The quick brown fox jumped over the lazy dog. Blah blah blah blah blah blah blah ...

(HTML after)

These links will disable / enable the text area above.

## dijit.form.DateTextBox:

(HTML inline before) 12/30/2005 (HTML after)

## dijit.form.TimeTextBox:

(HTML inline before) 9:00 AM (HTML after)

## dijit.form.FilteringSelect + Inline + remote data store:

(HTML inline before) Indiana (HTML after)

### Source 1

Item X
Item Y
Item Z

### Source 2

Item 1
Item 2
Item 3
This pane is closable, just for the icon ...

You can explore this single page after applying a Theme for use in creation of your own theme.

I am whole slew of Widgets on a page. Jump to dijit tests to test individual components.

There is a right-click [context] pop-up menu here, as well.

I am the last Tab

I am the second dialog. I am parented by the Low Tab Pane #3